%% Constructs the grid for teh CARA case for all domains
function g = construct_grid_cara(grid, data)

%% scalars
delta = .95;

%% 401k - constants
r_m = .0103426;
s_m = .028517;
r_f = .0035559;
riskpr = (r_m-r_f)/s_m^2;
avg_rfree = mean(data.fin.rfree(data.fin.rfree~=1 & data.fin.rfree~=0));
alpha = 1-avg_rfree;

%% STD
% define std shock for cara estimates
% price = price/46000*group_wage
% shock = shock*group_wage
% we only have one coverage tier - need to change that in cutoffs
% save identifiers, export with grid

% NOTE: menu is defined for STDI by wage group and option
[dcara.std.opts, I, grid.std.menu] = unique([data.std.opts, data.wage_avg], 'rows');
dcara.std.nmenus = size(dcara.std.opts, 1);		% number of menus

for m = 1:dcara.std.nmenus
    wage_group = dcara.std.opts(m,end);
    std_covg = dcara.std.opts(m,1:3);
    % price for this group = std.price/46000 * wage_group
    dcara.std.price(m,:) = unique(data.std.price, 'rows')/46000*wage_group;
    % define the cost under each option - shock is measured as fraction of
    % the year on disability
    dcara.std.oop{m} = kron(data.std.shock,1-std_covg).*wage_group;
end

% find cutoffs for std domain
'std'
for k_std = 1:size(grid.l_std,2)
    k_std
    % for each value of lambda, compute a matrix of cutoffs of size - groups by 6
    % group is each set of individuals for whom we need to compute a different set of cutoffs
    % this is defined by coverage tier and prices (or menu)
    grid.std.cutoffs{k_std} = cutoffs(grid.l_std(k_std), dcara.std);
end


%% LTD
% define ltd shock for cara estimates
% price = price/46000*group_wage
% shock = shock*group_wage

d = [1,delta,delta*delta,delta*delta*delta];

% see the notes for this - all we need to do is multiply the price vector 
% by delta, and the shocks by delta everything else is the same as for stdi
[dcara.ltd.opts, I, grid.ltd.menu] = unique([data.ltd.opts, data.wage_avg], 'rows');
dcara.ltd.nmenus = size(dcara.ltd.opts, 1);		% number of menus

for m = 1:dcara.ltd.nmenus
    % NOTE: menu is defined for LTDI by wage group and option
    wage_group = dcara.ltd.opts(m, end);  
    ltd_covg = dcara.ltd.opts(m,1:3);
    dcara.ltd.price(m, :) = unique(data.ltd.price, 'rows')/46000*wage_group*sum(d);
    % define the cost under each option
    data.ltd.shock_all = data.ltd.shock*d';
    dcara.ltd.oop{m} = kron(data.ltd.shock_all, 1-ltd_covg).*wage_group;
end

% find cutoffs for ltd domain
'ltd'
for k_ltd = 1:size(grid.l_ltd,2)
    k_ltd
    grid.ltd.cutoffs{k_ltd} = cutoffs(grid.l_ltd(k_ltd), dcara.ltd);
end

%% HI
% defined by prices and coverage tier. wages will cancel out
[dcara.hi.opts, I, grid.hi.menu] = unique([data.hi.price, data.hi.covgtier], 'rows');
dcara.hi.nmenus = size(dcara.hi.opts, 1);		

for m = 1:dcara.hi.nmenus 
    % unique set of prices for each coverage tier
    dcara.hi.price(m,:) = dcara.hi.opts(m,1:5);
    % menu defined as coverage tier, price vector
    dcara.hi.oop{m} = data.hi.oop(find(data.hi.covgtier == dcara.hi.opts(m,end)),:);
end

% Compute cutoffs
'hi'
for k_hi = 1:size(grid.l_hi,2)
    k_hi
    % for each value of lambda, compute a matrix of cutoffs of size - groups by 6
    % group is each set of individuals for whom we need to compute a different set of cutoffs
    % this is defined by coverage tier and prices (or menu)
    grid.hi.cutoffs{k_hi} = cutoffs(grid.l_hi(k_hi), dcara.hi);
end

%% RX
[dcara.rx.opts, I, grid.rx.menu] = unique([data.rx.price, data.rx.covgtier], 'rows');
dcara.rx.nmenus = size(dcara.rx.opts, 1);		

for m = 1:dcara.rx.nmenus
    dcara.rx.price(m,:) = dcara.rx.opts(m,1:3);
    dcara.rx.oop{m} = data.rx.oop(find(data.rx.covgtier == dcara.rx.opts(m,end)),:);
end

'rx'
for k_rx = 1:size(grid.l_rx,2)
    k_rx
    grid.rx.cutoffs{k_rx} = cutoffs(grid.l_rx(k_rx), dcara.rx);
end

%% DENTAL
[dcara.dental.opts, I, grid.dental.menu] = unique([data.dental.price, data.dental.covgtier], 'rows');
dcara.dental.nmenus = size(dcara.dental.opts, 1);		

for m = 1:dcara.dental.nmenus
    dcara.dental.price(m,:) = dcara.dental.opts(m,1:2);
    dcara.dental.oop{m} = data.dental.oop(find(data.dental.covgtier == dcara.dental.opts(m,end)),:);
end

'dental'
for k_d = 1:size(grid.l_dental,2)
    k_d
    grid.dental.cutoffs{k_d} = cutoffs(grid.l_dental(k_d), dcara.dental);
end

%% 401k - discrete
[dcara.fin.opts, I, grid.fin.menu] = unique([data.wage_avg], 'rows');
'Financial menu'
tabulate(grid.fin.menu)

dcara.fin.nmenus = size(dcara.fin.opts, 1);
for k_fin = 1:size(grid.l_fin, 2)
    for m = 1:dcara.fin.nmenus
        wage = dcara.fin.opts(m);
        ub1 = 1/wage*2*grid.l_fin(k_fin)*riskpr/(1+alpha);
        ub2 = 1/wage*2*grid.l_fin(k_fin)*riskpr/alpha;
        grid.fin_disc.cutoffs{k_fin}(m,:) = max([0,ub1, ub1,ub2, ub2, inf],0);
    end
end

% 401k - continuous - what is the right formula to use?
eps = 10^(-6);
share(:,2) = (1-data.fin.rfree).*data.wage_avg;
share(:,1) = (1-data.fin.rfree + eps).*data.wage_avg;
share((share(:,2)==1),1) = inf;					% for 100% in risky they could be at a corner
%% CHECK THIS LINE
grid.fin.cutoffs = riskpr*1./share; % multiply by k_fin in the overlap_all file

grid
save(grid.name, 'grid')
end
