%% Finds the indifference point for LTD insurance when using a CRRA utlity fn. 
function f = cutoffs_crra_ltd(d, l, ltd_shock, ltd_covg)

nopts = 3;
ltd_price = [0, 70, 120]/46000;
dim = ones(size(ltd_shock, 1),4);

for i = 1:nopts
    cons(:, i) = .3*((kron(1-ltd_price(i), dim) - l * kron(ltd_shock, 1-ltd_covg(i)))*[1,d,d*d,d*d*d]');
end

for opt1 = 1:nopts-1
    for opt2 = (opt1+1):nopts
        
        % if risk neutral always prefers option 2, then option 1 is never
        % chosen, define the cutoff as -10
        if mean(cons(:,opt1)) < mean(cons(:,opt2))
            cutoff(opt1, opt2) = -10;
            
            % if the consumption in option 1 is ever negative, then option 1 is
            % never chose, define the cutoff as -10
        elseif min(cons(:,1)) <= 0
            cutoff(opt1, opt2) = -10;
			            
        else
            [cutoff(opt1, opt2),fval,exitflag(1)] = fzero(@(x) ltd_diff(l, x, cons(:,opt1), cons(:,opt2)),1);
        end
    end
end

% check whether option 3 is feasible (i.e. min(cons)>0)
temp = zeros(1,nopts-1);
for t = 1:nopts-1
    temp(t) = min(cutoff(t,t+1:nopts));
    cutoff_interval(t) = max([temp(1:t),0]);
end

% upper cutoff for most generous option
if min(cons(:,3)) <= 0
    cutoff_interval(nopts) = 0;
	
else
    cutoff_interval(nopts) = inf;
end

f = [0, cutoff_interval];
end
