set more off
capture log close
clear
clear matrix
set mem 1g

local c_date = c(current_date)
local c_date = subinstr("`c_date'", " ", "_", .)
log using ../log/table2_`c_date', text replace

global hubid_list_2004="1858_1 1789_1 1818_2 2878_6 1854_1 131_1 1851_1 1852_1 1806_2 964_1 950_1 1764_3 128_1"

use ../dta/sample_080911.dta, replace

* TABLE 2 COLUMN 1
* ***********************************************************
recode rfree_cont (min/0.00001 = 1 "0%") (0.00001/.25 = 2 ">0-25%") (.25/.5 = 3 "25-50%") (.5/.75 = 4 "50-75%") (.75/.9999 = 5 "75-100%") (.9999/1.01 = 7 "100%"), gen(rfree_recode2)
tabout hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_recode2 using ../output/tabulation_choices.csv, oneway replace style(tab) lines(single) c(freq col) f(0c 1p)clab(No. Col_%)

* Table 2 - counterfactuals - columns 2-4
* ***********************************************************
* premium saving relative to safest option
* HI
gen hi_price_5_1 = price_tag_5 - price_tag_1
gen hi_price_5_2 = price_tag_5 - price_tag_2
gen hi_price_5_3 = price_tag_5 - price_tag_3
gen hi_price_5_4 = price_tag_5 - price_tag_4

* DRUG
gen drug_price_3_1 = drug_price_tag_3 - drug_price_tag_1
gen drug_price_3_2 = drug_price_tag_3 - drug_price_tag_2

* Dental
gen dental_price_2_1 = dental_price_tag_2 - dental_price_tag_1

* STDI - realized average in the sample given true wage
gen std_price_3_1 = (stdplan_price_3 - stdplan_price_1)/46000*wage_amt_hr
gen std_price_3_2 = (stdplan_price_3 - stdplan_price_2)/46000*wage_amt_hr

* LTDI - average in sample
gen ltd_price_3_1 = (ltdplan_price_3 - ltdplan_price_1)/46000*wage_amt_hr
gen ltd_price_3_2 = (ltdplan_price_3 - ltdplan_price_2)/46000*wage_amt_hr

* HI - expected avoided cost (using predictions2004.do)
* excess oop from not choosing safest coverage
gen oop_5_1 = proop4 - proop8
gen oop_5_2 = proop5 - proop8
gen oop_5_3 = proop6 - proop8
gen oop_5_4 = proop7 - proop8

gen hi_s = (covg_tierrecode==1)
gen hi_f = (covg_tierrecode==2)
gen hi_es = (covg_tierrecode==3)
gen hi_ec = (covg_tierrecode==4)

gen deduct_rx = hi_s* 50 + (hi_f + hi_es + hi_ec)* 100

gen rx_total_mail = rx_total_mail_brand + rx_total_mail_generic + rx_total_mail_other
gen rx_total_brand = rx_total_retail_brand + rx_total_mail_brand
gen rx_total_generic = rx_total_retail_generic + rx_total_mail_generic
gen rx_mail_share = rx_total_mail/rx_total
gen rx_brand_share = rx_total_brand/rx_total
gen rx_generic_share = rx_total_generic/rx_total

* in order - rx_total_retail_brand, rx_total_mail_brand, rx_total_retail_generic, rx_total_mail_generic
gen rx1 = deduct_rx - rx_total_retail_brand
gen rx2 = rx1 - rx_total_mail_brand
gen rx3 = rx2 - rx_total_retail_generic
gen rx4 = rx3 - rx_total_mail_generic

gen rxoop1 = min(deduct_rx, rx_total) + (rx1<0)* .5*(-rx1) + (rx2<0)*.4*(-rx2) + (rx3<0)*.2*(-rx3) + (rx4<0)*.1*(-rx4)
gen rxoop2 = min(deduct_rx, rx_total) + (rx1<0)* .4*(-rx1) + (rx2<0)*.3*(-rx2) + (rx3<0)*.2*(-rx3) + (rx4<0)*.1*(-rx4)
gen rxoop3 = min(deduct_rx, rx_total) + (rx1<0)* .3*(-rx1) + (rx2<0)*.2*(-rx2) + (rx3<0)*.2*(-rx3) + (rx4<0)*.1*(-rx4)

gen rx_oop_1 = min(deduct_rx, rx_total) + ((rx_total-deduct_rx)>0)*(.5*rx_total_retail_brand + .4*rx_total_mail_brand)
gen rx_oop_2 = min(deduct_rx, rx_total) + ((rx_total-deduct_rx)>0)*(.4*rx_total_retail_brand + .3*rx_total_mail_brand)
gen rx_oop_3 = min(deduct_rx, rx_total) + ((rx_total-deduct_rx)>0)*(.3*rx_total_retail_brand + .2*rx_total_mail_brand)

gen rx_oop_3_1 = rx_oop_1 - rx_oop_3
gen rx_oop_3_2 = rx_oop_2 - rx_oop_3

gen dental_oop_2_1 = proop1 - proop2

* STDI benefit
gen std_benefit_1 = (wage_amt_hr/365) *std_days *stdplan_option_1/100
gen std_benefit_2 = (wage_amt_hr/365) *std_days *stdplan_option_2/100
gen std_benefit_3 = (wage_amt_hr/365) *std_days *stdplan_option_3/100

* avoided loss from choosing safest option
gen std_benefit_3_2 = std_benefit_3 - std_benefit_2
gen std_benefit_3_1 = std_benefit_3 - std_benefit_1
sum std_benefit_3_*

* LTDI benefit
gen ltd_benefit_1 = (wage_amt_hr/365) *ltd_days *ltdplan_option_1/100 
gen ltd_benefit_2 = (wage_amt_hr/365) *ltd_days* ltdplan_option_2/100
gen ltd_benefit_3 = (wage_amt_hr/365) *ltd_days* ltdplan_option_3/100

* avoided loss from choosing most coverage
gen ltd_benefit_3_2 = ltd_benefit_3 - ltd_benefit_2
gen ltd_benefit_3_1 = ltd_benefit_3 - ltd_benefit_1

* TABLE 2 - EXCEPT FOR 401K
sum hi_price_5_* oop_5_*
sum drug_price_3_1 drug_price_3_2 rx_oop_3_*
sum dental_price_2_1 dental_oop_2_1
sum std_price_3_* std_benefit_3_*
sum ltd_price_3_* ltd_benefit_3_*

* TABLE 2 - 401K
sum total_emp_cont 
gen avg_cont = r(mean)

drop share*
* this gets us $-weighted shares at the market level
foreach hub of global hubid_list_2004 {
	qui: sum hub_emp_cont_`hub'
	gen share_`hub' = r(mean)/avg_cont
}

preserve
keep in 1
keep share*
gen order = 1
sort order
list
save ../dta/share.dta, replace
restore

set seed 2038947

* dataset with monthly returns for all the funds for 29 months
use ../dta/complete_monthly_returns, clear

capture program drop ryear
program define ryear, rclass
	preserve
	bsample 12
	foreach hub of global hubid_list_2004 {
		replace return_`hub' = log(1+return_`hub'/100)
		egen ryear_`hub' = sum(return_`hub')
		replace ryear_`hub' = exp(ryear_`hub')
	}
	drop order
	gen order = 1
	sort order
	merge order using ../dta/share.dta
	tab _merge
	drop _merge
	* draw of yearly returns for each fund
	sum ryear*
	* return of the risk free portfolio has the same shares as $share in the full sample
	gen ryear_free = (share_1764_3* ryear_1764_3 +share_1818_2*ryear_1818_2)/(share_1818_2+share_1764_3)
	list
	gen ryear_risky = (share_1858_1*ryear_1858_1 + share_1789_1*ryear_1789_1 + share_2878_6*ryear_2878_6 + share_1854_1*ryear_1854_1 + share_131_1*ryear_131_1 + share_1851_1*ryear_1851_1 + share_1852_1*ryear_1852_1 + share_1806_2*ryear_1806_2 + share_964_1*ryear_964_1 + share_950_1*ryear_950_1 + share_128_1*ryear_128_1)/(share_1858_1+ share_1789_1+ share_2878_6+ share_1854_1+ share_131_1 + share_1851_1+ share_1852_1+ share_1806_2+share_964_1+ share_950_1 + share_128_1) 
	gen rshare50 = .5*ryear_free+.5*ryear_risky
	gen rshare0 = 0*ryear_free+1*ryear_risky
	gen rshare100 = 1*ryear_free+0*ryear_risky
	gen rshare100_0 = (rshare100-rshare0)*4616.236
	gen rshare100_50 = (rshare100-rshare50)*4616.236
	
	sum rshare0
	return scalar rshare0 = r(mean)
	sum rshare50
	return scalar rshare50 = r(mean)
	sum rshare100
	return scalar rshare100 = r(mean)
	sum rshare100_0
	return scalar rshare100_0 = r(mean)
	sum rshare100_50
	return scalar rshare100_50 = r(mean)
	restore
end

simulate r100_0=r(rshare100_0) r100_50=r(rshare100_50) r0=r(rshare0) r50=r(rshare50) r100=r(rshare100), reps(1500): ryear
sum r*

